.. _developers-guide-index:

=================
Developer's Guide
=================

.. toctree::
    :maxdepth: 2
    
    Overview <overview/index>
    Writting macros <howto_macros>
    Writting controllers <howto_controllers>
    API <api/sardana>
    Migration guide <guide_migration>
    Examples <examples/examples>
    Development guidelines <guide_coding>